# Changelog for straitjacket

## v202104.1018

- Update vendored black to 21.4b2


## v202104.1017

- Update vendored black to 21.4b1


## v202008.1016

- Bugfix: Bad path handling at root level.


## v202008.1015

- Update vendored black to 20.8b1


## v202008.1014

- Vendor black from master
- Fix issue with multiprocessing/fork on MacOS


## v201910.0011-beta

- Update for release of black==19.10b0


## v201904.0010-beta

- Update for release of black==19.3b0


## v201812.0007-alpha

- TLDR: more bugfixes and updated documentation


## v201812.0006-alpha

TLDR: no major changes, just bug fixes.

- Fixed #1: Disable right alignment of numbers when not preceded by a number.
- Fixed #3: Disable alignment when preceded by a multiline string.
- Fixed #4: Excessive whitespace in non aligned context.
- Fixed #8: Double and single quotes around strings not consistent


## v201810.0004-alpha

- Initial release
